@@ -8,6 +8,7 @@
 
     options: {
 		url: "heartbeat_default.asp",
+		counter: 0,
 		delay: 10000
     },
 	
@@ -36,8 +37,10 @@
     },
 
     beat: function() {
-		$("#HeartBeatDIV").load(this.options.url);
+                var c = this.options.url.search(/\?/) == -1 ? '?' : '&' ; 
+		var newUrl = this.options.url + c + "counter=" + this.options.counter++ ; 
+		$("#HeartBeatDIV").load(newUrl);
 		this.timeoutobj.id = setTimeout("$.jheartbeat.beat();", this.options.delay);
         this.beatfunction();
     }
-};
\ No newline at end of file
+};
